@@ -910,10 +910,10 @@ indent <- function(lines, depth = 4L){
 #' @noRd
 safe_json <- function(path, encoding = 'UTF-8', ...){
 
-    lines <- readLines(con = path, encoding = encoding)
-
     log_trace('Reading JSON from `%s` (encoding: %s).', path, encoding)
 
+    lines <- readLines(con = path, encoding = encoding)
+
     json_ok <- jsonlite::validate(txt = lines)
 
     log_trace('JSON validation successful: %s', json_ok)
@@ -960,6 +960,16 @@ safe_json <- function(path, encoding = 'UTF-8', ...){
 }
 
 
+#' Bypassing slow doctests is enabled
+#'
+#' @noRd
+.doctest_bypass <- function() {
+
+    omnipathr.env$doctest_bypass
+
+}
+
+
 #' Bypass slow doctests
 #'
 #' Makes the calling function return a value, bypassing further execution.
@@ -976,7 +986,7 @@ safe_json <- function(path, encoding = 'UTF-8', ...){
 #' @noRd
 .slow_doctest <- function(value = NULL, env = parent.frame()){
 
-    if(.on_buildserver()){
+    if(.doctest_bypass() && .on_buildserver()){
 
         log_trace('Bypassing call: `%s`.', deparse(sys.call(-1L)))
         log_trace(paste(
@@ -992,6 +1002,16 @@ safe_json <- function(path, encoding = 'UTF-8', ...){
 }
 
 
+#' Disable bypassing slow doctests
+#'
+#' @noRd
+disable_doctest_bypass <- function() {
+
+    omnipathr.env$doctest_bypass <- FALSE
+
+}
+
+
 #' Packages that seem to be missing from library
 #'
 #' @importFrom magrittr %>%
@@ -1438,3 +1458,45 @@ ensure_character <- function(d, ...) {
     d %>% mutate(across(c(!!!cols), as.character))
 
 }
+
+
+#' Checks if an object has names
+#'
+#' @param value An object
+#'
+#' @return `TRUE` if the object has names, `FALSE` otherwise
+#'
+#' @importFrom magrittr %>% not
+#' @noRd
+named <- function(value) {
+
+    names(value) %>% is.null %>% not
+
+}
+
+
+#' Checks if all names of a list or vector are non-empty
+#'
+#' @param value A list or vector.
+#'
+#' @return `TRUE` if all names are non-empty, `FALSE` otherwise
+#'
+#' @importFrom magrittr %>%
+#' @importFrom purrr map_lgl
+#' @noRd
+all_named <- function(value) {
+
+    value %>% names %>% map_lgl(~ !is.na(.x) && nchar(.x) > 0L) %>% all
+
+}
+
+
+#' Last element of a list or vector
+#'
+#' @importFrom magrittr %>%
+#' @noRd
+last <- function(value) {
+
+    value[length(value)] %>% unlist
+
+}
