@@ -690,17 +690,14 @@ omnipath_build_url <- function(param, notls = FALSE){
 
     }
 
-    url <-
-        .omnipath_querystring_param %>%
-        reduce(
-            function(url, key){
-                omnipath_url_add_param(url, key, param[[key]])
-            },
-            .init = baseurl
-        ) %>%
-        URLencode
-
-    return(url)
+    .omnipath_querystring_param %>%
+    reduce(
+        function(url, key){
+            omnipath_url_add_param(url, key, param[[key]])
+        },
+        .init = baseurl
+    ) %>%
+    URLencode
 
 }
 
@@ -1196,7 +1193,8 @@ omnipath_download <- function(url, fun, cache = NULL, ...) {
                     the_url,
                     conditionMessage(e)
                 )
-                log_all_info('OmnipathR')
+                nothing <- log_all_info('OmnipathR')
+                NULL
             }
         )
 
